==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/undo/undoAddItem.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/undo/undoAddItem", ['module', 'exports', 'require', '../../thunks/deleteItem'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.undoAction = undoAction;
    exports.getDerivedStateForUndo = getDerivedStateForUndo;

    var _deleteItem = _interopRequireDefault(require("../../thunks/deleteItem"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function undoAction(_ref) {
      var action = _ref.action,
          store = _ref.store;
      var itemId = action.itemId;
      return (0, _deleteItem["default"])({
        itemId: itemId,
        store: store
      });
    }

    function getDerivedStateForUndo(_ref2) {
      var action = _ref2.action;
      return {
        itemId: action.itemId
      };
    }
    //# sourceMappingURL=undoAddItem.js.map
  }
});
//# sourceMappingURL=undoAddItem.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/undo/undoAddItem.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/undo/undoAddItem", ['module', 'exports', 'require', '../../thunks/deleteItem'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.undoAction = undoAction;
    exports.getDerivedStateForUndo = getDerivedStateForUndo;

    var _deleteItem = _interopRequireDefault(require("../../thunks/deleteItem"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function undoAction(_ref) {
      var action = _ref.action,
          store = _ref.store;
      var itemId = action.itemId;
      return (0, _deleteItem.default)({
        itemId: itemId,
        store: store
      });
    }

    function getDerivedStateForUndo(_ref2) {
      var action = _ref2.action;
      return {
        itemId: action.itemId
      };
    }
    //# sourceMappingURL=undoAddItem.js.map
  }
});
//# sourceMappingURL=undoAddItem.js.map
